==> iot-1.93.0-sources.jar: software/amazon/awscdk/services/iot/CfnThingPrincipalAttachmentProps.java <==
package software.amazon.awscdk.services.iot;

/**
 * Properties for defining a `AWS::IoT::ThingPrincipalAttachment`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.753Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iot.$Module.class, fqn = "@aws-cdk/aws-iot.CfnThingPrincipalAttachmentProps")
@software.amazon.jsii.Jsii.Proxy(CfnThingPrincipalAttachmentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnThingPrincipalAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::IoT::ThingPrincipalAttachment.Principal`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPrincipal();

    /**
     * `AWS::IoT::ThingPrincipalAttachment.ThingName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getThingName();

    /**
     * @return a {@link Builder} of {@link CfnThingPrincipalAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnThingPrincipalAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnThingPrincipalAttachmentProps> {
        private java.lang.String principal;
        private java.lang.String thingName;

        /**
         * Sets the value of {@link CfnThingPrincipalAttachmentProps#getPrincipal}
         * @param principal `AWS::IoT::ThingPrincipalAttachment.Principal`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder principal(java.lang.String principal) {
            this.principal = principal;
            return this;
        }

        /**
         * Sets the value of {@link CfnThingPrincipalAttachmentProps#getThingName}
         * @param thingName `AWS::IoT::ThingPrincipalAttachment.ThingName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder thingName(java.lang.String thingName) {
            this.thingName = thingName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnThingPrincipalAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnThingPrincipalAttachmentProps build() {
            return new Jsii$Proxy(principal, thingName);
        }
    }

    /**
     * An implementation for {@link CfnThingPrincipalAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnThingPrincipalAttachmentProps {
        private final java.lang.String principal;
        private final java.lang.String thingName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.principal = software.amazon.jsii.Kernel.get(this, "principal", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.thingName = software.amazon.jsii.Kernel.get(this, "thingName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String principal, final java.lang.String thingName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.principal = java.util.Objects.requireNonNull(principal, "principal is required");
            this.thingName = java.util.Objects.requireNonNull(thingName, "thingName is required");
        }

        @Override
        public final java.lang.String getPrincipal() {
            return this.principal;
        }

        @Override
        public final java.lang.String getThingName() {
            return this.thingName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("principal", om.valueToTree(this.getPrincipal()));
            data.set("thingName", om.valueToTree(this.getThingName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iot.CfnThingPrincipalAttachmentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnThingPrincipalAttachmentProps.Jsii$Proxy that = (CfnThingPrincipalAttachmentProps.Jsii$Proxy) o;

            if (!principal.equals(that.principal)) return false;
            return this.thingName.equals(that.thingName);
        }

        @Override
        public final int hashCode() {
            int result = this.principal.hashCode();
            result = 31 * result + (this.thingName.hashCode());
            return result;
        }
    }
}

==> iot-1.182.0-sources.jar: software/amazon/awscdk/services/iot/CfnThingPrincipalAttachmentProps.java <==
package software.amazon.awscdk.services.iot;

/**
 * Properties for defining a `CfnThingPrincipalAttachment`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.iot.*;
 * CfnThingPrincipalAttachmentProps cfnThingPrincipalAttachmentProps = CfnThingPrincipalAttachmentProps.builder()
 *         .principal("principal")
 *         .thingName("thingName")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:36.112Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iot.$Module.class, fqn = "@aws-cdk/aws-iot.CfnThingPrincipalAttachmentProps")
@software.amazon.jsii.Jsii.Proxy(CfnThingPrincipalAttachmentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnThingPrincipalAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The principal, which can be a certificate ARN (as returned from the `CreateCertificate` operation) or an Amazon Cognito ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPrincipal();

    /**
     * The name of the AWS IoT thing.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getThingName();

    /**
     * @return a {@link Builder} of {@link CfnThingPrincipalAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnThingPrincipalAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnThingPrincipalAttachmentProps> {
        java.lang.String principal;
        java.lang.String thingName;

        /**
         * Sets the value of {@link CfnThingPrincipalAttachmentProps#getPrincipal}
         * @param principal The principal, which can be a certificate ARN (as returned from the `CreateCertificate` operation) or an Amazon Cognito ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder principal(java.lang.String principal) {
            this.principal = principal;
            return this;
        }

        /**
         * Sets the value of {@link CfnThingPrincipalAttachmentProps#getThingName}
         * @param thingName The name of the AWS IoT thing. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder thingName(java.lang.String thingName) {
            this.thingName = thingName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnThingPrincipalAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnThingPrincipalAttachmentProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnThingPrincipalAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnThingPrincipalAttachmentProps {
        private final java.lang.String principal;
        private final java.lang.String thingName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.principal = software.amazon.jsii.Kernel.get(this, "principal", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.thingName = software.amazon.jsii.Kernel.get(this, "thingName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.principal = java.util.Objects.requireNonNull(builder.principal, "principal is required");
            this.thingName = java.util.Objects.requireNonNull(builder.thingName, "thingName is required");
        }

        @Override
        public final java.lang.String getPrincipal() {
            return this.principal;
        }

        @Override
        public final java.lang.String getThingName() {
            return this.thingName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("principal", om.valueToTree(this.getPrincipal()));
            data.set("thingName", om.valueToTree(this.getThingName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iot.CfnThingPrincipalAttachmentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnThingPrincipalAttachmentProps.Jsii$Proxy that = (CfnThingPrincipalAttachmentProps.Jsii$Proxy) o;

            if (!principal.equals(that.principal)) return false;
            return this.thingName.equals(that.thingName);
        }

        @Override
        public final int hashCode() {
            int result = this.principal.hashCode();
            result = 31 * result + (this.thingName.hashCode());
            return result;
        }
    }
}
